        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 23 <br>2,4,5,7,8,10,11,13,14,17,18,20,25,26,28,29,31,32,33,38,40,44,47';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 21 <strong>control</strong><br>0,6,9,12,15,19,21,22,23,24,27,30,34,36,39,41,42,43,45,49,50';}
       if(rr==4 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>48</strong> miembros: 7 <br>1,3,16,35,37,46,48';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 23 <br>2,4,5,7,8,10,11,13,14,17,18,20,25,26,28,29,31,32,33,38,40,44,47';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 21 <strong>control</strong><br>0,6,9,12,15,19,21,22,23,24,27,30,34,36,39,41,42,43,45,49,50';}
       if(rr==23 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>48</strong> miembros: 7 <br>1,3,16,35,37,46,48';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 23 <br>2,4,5,7,8,10,11,13,14,17,18,20,25,26,28,29,31,32,33,38,40,44,47';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 21 <strong>control</strong><br>0,6,9,12,15,19,21,22,23,24,27,30,34,36,39,41,42,43,45,49,50';}
       if(rr==25 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>48</strong> miembros: 7 <br>1,3,16,35,37,46,48';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 23 <br>2,4,5,7,8,10,11,13,14,17,18,20,25,26,28,29,31,32,33,38,40,44,47';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 21 <strong>control</strong><br>0,6,9,12,15,19,21,22,23,24,27,30,34,36,39,41,42,43,45,49,50';}
       if(rr==26 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>48</strong> miembros: 7 <br>1,3,16,35,37,46,48';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 23 <br>2,4,5,7,8,10,11,13,14,17,18,20,25,26,28,29,31,32,33,38,40,44,47';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 21 <strong>control</strong><br>0,6,9,12,15,19,21,22,23,24,27,30,34,36,39,41,42,43,45,49,50';}
       if(rr==27 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>48</strong> miembros: 7 <br>1,3,16,35,37,46,48';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 23 <br>2,4,5,7,8,10,11,13,14,17,18,20,25,26,28,29,31,32,33,38,40,44,47';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 21 <strong>control</strong><br>0,6,9,12,15,19,21,22,23,24,27,30,34,36,39,41,42,43,45,49,50';}
       if(rr==28 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260526 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>48</strong> miembros: 7 <br>1,3,16,35,37,46,48';}
}
